@@ -23,8 +23,8 @@
 #include "Emulation.h"
 
 // System
-#include <stdio.h>
-#include <stdlib.h>
+#include <cstdio>
+#include <cstdlib>
 #include <unistd.h>
 #include <string>
 
@@ -51,10 +51,10 @@
 using namespace Konsole;
 
 Emulation::Emulation() :
-  _currentScreen(0),
-  _codec(0),
-  _decoder(0),
-  _keyTranslator(0),
+  _currentScreen(nullptr),
+  _codec(nullptr),
+  _decoder(nullptr),
+  _keyTranslator(nullptr),
   _usesMouse(false),
   _bracketedPasteMode(false)
 {
@@ -73,7 +73,7 @@ Emulation::Emulation() :
            SLOT(bracketedPasteModeChanged(bool)));
 
   connect(this, &Emulation::cursorChanged, [this] (KeyboardCursorShape cursorShape, bool blinkingCursorEnabled) {
-    emit titleChanged( 50, QString("CursorShape=%1;BlinkingCursorEnabled=%2")
+    emit titleChanged( 50, QString(QLatin1String("CursorShape=%1;BlinkingCursorEnabled=%2"))
                                .arg(static_cast<int>(cursorShape)).arg(blinkingCursorEnabled) );
   });
 }
@@ -214,7 +214,7 @@ void Emulation::sendKeyEvent( QKeyEvent* ev )
   { // A block of text
     // Note that the text is proper unicode.
     // We should do a conversion here
-    emit sendData(ev->text().toUtf8(),ev->text().length());
+    emit sendData(ev->text().toUtf8().constData(),ev->text().length());
   }
 }
 
@@ -380,7 +380,7 @@ void Emulation::setImageSize(int lines, int columns)
 
 QSize Emulation::imageSize() const
 {
-  return QSize(_currentScreen->getColumns(), _currentScreen->getLines());
+  return {_currentScreen->getColumns(), _currentScreen->getLines()};
 }
 
 ushort ExtendedCharTable::extendedCharHash(ushort* unicodePoints , ushort length) const
@@ -398,7 +398,7 @@ bool ExtendedCharTable::extendedCharMatch(ushort hash , ushort* unicodePoints ,
 
     // compare given length with stored sequence length ( given as the first ushort in the
     // stored buffer )
-    if ( entry == 0 || entry[0] != length )
+    if ( entry == nullptr || entry[0] != length )
        return false;
     // if the lengths match, each character must be checked.  the stored buffer starts at
     // entry[1]
@@ -458,7 +458,7 @@ ushort* ExtendedCharTable::lookupExtendedChar(ushort hash , ushort& length) cons
     else
     {
         length = 0;
-        return 0;
+        return nullptr;
     }
 }
 
