@@ -55,7 +55,7 @@ public:
     /**
      * Constructor
      */
-    KPtyDevice(QObject *parent = 0);
+    KPtyDevice(QObject *parent = nullptr);
 
     /**
      * Destructor:
@@ -63,14 +63,14 @@ public:
      *  If the pty is still open, it will be closed. Note, however, that
      *  an utmp registration is @em not undone.
      */
-    virtual ~KPtyDevice();
+    ~KPtyDevice() override;
 
     /**
      * Create a pty master/slave pair.
      *
      * @return true if a pty pair was successfully opened
      */
-    virtual bool open(OpenMode mode = ReadWrite | Unbuffered);
+    bool open(OpenMode mode = ReadWrite | Unbuffered) override;
 
     /**
      * Open using an existing pty master. The ownership of the fd
@@ -90,7 +90,7 @@ public:
     /**
      * Close the pty master/slave pair.
      */
-    virtual void close();
+    void close() override;
 
     /**
      * Sets whether the KPtyDevice monitors the pty for incoming data.
@@ -119,30 +119,30 @@ public:
     /**
      * @return always true
      */
-    virtual bool isSequential() const;
+    bool isSequential() const override;
 
     /**
      * @reimp
      */
-    bool canReadLine() const;
+    bool canReadLine() const override;
 
     /**
      * @reimp
      */
-    bool atEnd() const;
+    bool atEnd() const override;
 
     /**
      * @reimp
      */
-    qint64 bytesAvailable() const;
+    qint64 bytesAvailable() const override;
 
     /**
      * @reimp
      */
-    qint64 bytesToWrite() const;
+    qint64 bytesToWrite() const override;
 
-    bool waitForBytesWritten(int msecs = -1);
-    bool waitForReadyRead(int msecs = -1);
+    bool waitForBytesWritten(int msecs = -1) override;
+    bool waitForReadyRead(int msecs = -1) override;
 
 
 Q_SIGNALS:
@@ -154,9 +154,9 @@ Q_SIGNALS:
     void readEof();
 
 protected:
-    virtual qint64 readData(char *data, qint64 maxSize);
-    virtual qint64 readLineData(char *data, qint64 maxSize);
-    virtual qint64 writeData(const char *data, qint64 maxSize);
+    qint64 readData(char *data, qint64 maxSize) override;
+    qint64 readLineData(char *data, qint64 maxSize) override;
+    qint64 writeData(const char *data, qint64 maxSize) override;
 
 private:
     Q_PRIVATE_SLOT(d_func(), bool _k_canRead())
@@ -278,7 +278,7 @@ public:
     {
         int index = 0;
         int start = head;
-        QLinkedList<QByteArray>::ConstIterator it = buffers.begin();
+        QLinkedList<QByteArray>::ConstIterator it = buffers.constBegin();
         forever {
             if (!maxLength)
                 return index;
@@ -339,7 +339,7 @@ struct KPtyDevicePrivate : public KPtyPrivate {
     KPtyDevicePrivate(KPty* parent) :
         KPtyPrivate(parent),
         emittedReadyRead(false), emittedBytesWritten(false),
-        readNotifier(0), writeNotifier(0)
+        readNotifier(nullptr), writeNotifier(nullptr)
     {
     }
 
