@@ -11,36 +11,32 @@ But in some cases (apple bundle) there can be more locations).
 */
 QString get_kb_layout_dir()
 {
-#ifdef BUNDLE_KEYBOARDLAYOUTS
-    return QLatin1String(":/");
-#else
 //    qDebug() << __FILE__ << __FUNCTION__;
 
-    QString rval = "";
-    QString k(KB_LAYOUT_DIR);
+    QString rval = QString();
+    QString k(QLatin1String(KB_LAYOUT_DIR));
     QDir d(k);
 
-    qDebug() << "default KB_LAYOUT_DIR: " << k;
+    //qDebug() << "default KB_LAYOUT_DIR: " << k;
 
     if (d.exists())
     {
-        rval = k.append("/");
+        rval = k.append(QLatin1Char('/'));
         return rval;
     }
 
     // subdir in the app location
-    d.setPath(QCoreApplication::applicationDirPath() + "/kb-layouts/");
+    d.setPath(QCoreApplication::applicationDirPath() + QLatin1String("/kb-layouts/"));
     //qDebug() << d.path();
     if (d.exists())
-        return QCoreApplication::applicationDirPath() + "/kb-layouts/";
-#ifdef Q_WS_MAC
-    d.setPath(QCoreApplication::applicationDirPath() + "/../Resources/kb-layouts/");
+        return QCoreApplication::applicationDirPath() + QLatin1String("/kb-layouts/");
+#ifdef Q_OS_MAC
+    d.setPath(QCoreApplication::applicationDirPath() + QLatin1String("/../Resources/kb-layouts/"));
     if (d.exists())
-        return QCoreApplication::applicationDirPath() + "/../Resources/kb-layouts/";
+        return QCoreApplication::applicationDirPath() + QLatin1String("/../Resources/kb-layouts/");
 #endif
-    qDebug() << "Cannot find KB_LAYOUT_DIR. Default:" << k;
+    //qDebug() << "Cannot find KB_LAYOUT_DIR. Default:" << k;
     return QString();
-#endif // BUNDLE_KEYBOARDLAYOUTS
 }
 
 /*! Helper function to add custom location of color schemes.
@@ -60,36 +56,33 @@ But in some cases (apple bundle) there can be more locations).
 */
 const QStringList get_color_schemes_dirs()
 {
-#ifdef BUNDLE_COLORSCHEMES
-    return QLatin1String(":/");
-#else
 //    qDebug() << __FILE__ << __FUNCTION__;
 
     QStringList rval;
-    QString k(COLORSCHEMES_DIR);
+    QString k(QLatin1String(COLORSCHEMES_DIR));
     QDir d(k);
 
 //    qDebug() << "default COLORSCHEMES_DIR: " << k;
 
     if (d.exists())
-        rval << k.append("/");
+        rval << k.append(QLatin1Char('/'));
 
     // subdir in the app location
-    d.setPath(QCoreApplication::applicationDirPath() + "/color-schemes/");
+    d.setPath(QCoreApplication::applicationDirPath() + QLatin1String("/color-schemes/"));
     //qDebug() << d.path();
     if (d.exists())
     {
         if (!rval.isEmpty())
             rval.clear();
-        rval << (QCoreApplication::applicationDirPath() + "/color-schemes/");
+        rval << (QCoreApplication::applicationDirPath() + QLatin1String("/color-schemes/"));
     }
-#ifdef Q_WS_MAC
-    d.setPath(QCoreApplication::applicationDirPath() + "/../Resources/color-schemes/");
+#ifdef Q_OS_MAC
+    d.setPath(QCoreApplication::applicationDirPath() + QLatin1String("/../Resources/color-schemes/"));
     if (d.exists())
     {
         if (!rval.isEmpty())
             rval.clear();
-        rval << (QCoreApplication::applicationDirPath() + "/../Resources/color-schemes/");
+        rval << (QCoreApplication::applicationDirPath() + QLatin1String("/../Resources/color-schemes/"));
     }
 #endif
     for (const QString& custom_dir : const_cast<const QStringList&>(custom_color_schemes_dirs))
@@ -106,5 +99,4 @@ const QStringList get_color_schemes_dirs()
     }
 #endif
     return rval;
-#endif // BUNDLE_COLORSCHEMES
 }
